# PLOT ROUTINES FOR GP MODELS.
#
# Radford M. Neal, 2010.


# PLOT GP PARAMETERS FROM MCMC RUN.

gp_plot <- function (r, which=NULL, thin=1, extract=gp_eig_extract, type=2)
{ 
  if (thin<1)
  { stop("Bad thin parameter")
  }

  e <- extract(r$X1,r$X2)
  N <- nrow(e$nu)
  D <- ncol(e$nu)

  if (is.null(which))
  { nu <- e$nu
    which <- seq_len(D)
  }
  else
  { nu <- e$nu[,which]
  }

  subset <- seq(1,N,by=thin)

  if (type!=0) 
  { par(mfrow=c(2,2))
  }

  if (type!=0)
  { 
    plot(c(1,N),range(nu),type="n",
         log="y",xlab="",ylab="nu")
    for (i in seq_len(ncol(nu)))
    { points (subset, nu[subset,i], col=i+1, pch=20)
      mtext(which[i],at=1+(i-1)*N/D,col=i+1)
    }
  }

  ave.nu <- rowMeans(e$nu)

  if (type==0)
  { plot(c(1,N),c(2e-3,1e+1),type="n",
         log="y",xlab="",ylab="average nu / eta / sigma")
  }
  else
  { plot(c(1,N),range(c(ave.nu,e$eta,e$sigma)),type="n",
         log="y",xlab="",ylab="average nu / eta / sigma")
  }
  points (subset, ave.nu[subset], col=2, pch=20)
  points (subset, e$eta[subset], col=3, pch=20)
  points (subset, e$sigma[subset], col=4, pch=20)
  mtext("average nu",adj=0,col=2)
  mtext("eta",col=3)
  mtext("sigma",adj=1,col=4)

  if (type!=0)
  { 
    show <- seq (round(N/3), N, by=ceiling((2*N/3)/2000))

    if (type==1)
    { plot(ave.nu[show],e$sigma[show],pch=20,log="xy",
           xlab="aveage nu",ylab="sigma")
    }
    else
    { plot(range(e$sigma),range(nu),type="n",log="xy",xlab="sigma",ylab="nu")
      for (i in seq_len(ncol(nu)))
      { points (e$sigma[show], nu[show,i], col=i+1, pch=20)
      }
    }
  }
 
  if (type!=0)
  {
    plot(e$eta[show],e$sigma[show],pch=20,log="xy",xlab="eta",ylab="sigma")
  }
}
